
# Class: chemical or drug or treatment




URI: [biolink:ChemicalOrDrugOrTreatment](https://w3id.org/biolink/vocab/ChemicalOrDrugOrTreatment)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Treatment]uses%20-.->[ChemicalOrDrugOrTreatment],[Drug]uses%20-.->[ChemicalOrDrugOrTreatment],[Treatment],[Drug])](https://yuml.me/diagram/nofunky;dir:TB/class/[Treatment]uses%20-.->[ChemicalOrDrugOrTreatment],[Drug]uses%20-.->[ChemicalOrDrugOrTreatment],[Treatment],[Drug])

## Mixin for

 * [Drug](Drug.md) (mixin)  - A substance intended for use in the diagnosis, cure, mitigation, treatment, or prevention of disease
 * [Treatment](Treatment.md) (mixin)  - A treatment is targeted at a disease or phenotype and may involve multiple drug 'exposures', medical devices and/or procedures

## Referenced by Class


## Attributes

